searchData={"content_type":"text/markdown","items":[{"doc":"Tiny module for image encoding and decoding.\n\nThe following formats are supported and have type u8:\n\n  * JPEG baseline & progressive (12 bpc/arithmetic not supported, same as stock IJG lib)\n  * PNG 1/2/4/8/16-bit-per-channel\n  * TGA\n  * BMP non-1bpp, non-RLE\n  * PSD (composited view only, no extra channels, 8/16 bit-per-channel)\n  * GIF (always reports as 4-channel)\n  * PIC (Softimage PIC)\n  * PNM (PPM and PGM binary only)\n\nThe following formats are supported and have type f32:\n\n  * HDR (radiance rgbE format) (type is f32)\n\nThere are also specific functions for working with GIFs.","ref":"StbImage.html","title":"StbImage","type":"module"},{"doc":"StbImage's can be passed to `Nx`'s numerical definitions\nand it will be automatically converted to tensors. You can\nalso explicitly convert to and from tensors using `to_nx/2`\nand `from_nx/1`.","ref":"StbImage.html#module-nx-integration","title":"Nx integration - StbImage","type":"module"},{"doc":"The `StbImage` struct.\n\nIt has the following fields:\n\n  * `:data` - a blob with the image bytes in HWC (heigth-width-channels) order\n  * `:shape` - a tuple with the `{height, width, channels}`\n  * `:type` - the type unit in the binary (`{:u, 8}` or `{:f, 32}`)\n\nThe number of channels correlates directly to the color mode.\n1 channel is greyscale, 2 is greyscale+alpha, 3 is RGB, and\n4 is RGB+alpha.","ref":"StbImage.html#__struct__/0","title":"StbImage.__struct__/0","type":"function"},{"doc":"Creates a `StbImage` from a Nx tensor.\n\nThe tensor is expected to have the shape `{h, w, c}`\nand one of the supported types (u8/f32).","ref":"StbImage.html#from_nx/1","title":"StbImage.from_nx/1","type":"function"},{"doc":"Creates a StbImage directly.\n\n`data` is a binary blob with the image bytes in HWC\n(heigth-width-channels) order. `shape` is a tuple\nwith the `heigth`, `width`, and `channel` dimensions.","ref":"StbImage.html#new/3","title":"StbImage.new/3","type":"function"},{"doc":"* `:type` - The type of the data. Defaults to `{:u, 8}`.\n    Must be one of `{:u, 8}` or `{:f, 32}`. The `:u8` and\n    `:f32` convenience atom syntax is also available.","ref":"StbImage.html#new/3-options","title":"Options - StbImage.new/3","type":"function"},{"doc":"Reads image from `binary` representing an image.","ref":"StbImage.html#read_binary/2","title":"StbImage.read_binary/2","type":"function"},{"doc":"* `:channels` - The number of desired channels.\n    Use `0` for auto-detection. Defaults to 0.","ref":"StbImage.html#read_binary/2-options","title":"Options - StbImage.read_binary/2","type":"function"},{"doc":"{:ok, buffer} = File.read(\"/path/to/image\")\n    {:ok, img} = StbImage.read_binary(buffer)\n    {h, w, c} = img.shape\n    img = img.data\n\n    # If you know that the image is a 4-channel image and auto-detection failed\n    {:ok, img} = StbImage.read_binary(buffer, channels: 4)\n    {h, w, c} = img.shape\n    img = img.data","ref":"StbImage.html#read_binary/2-example","title":"Example - StbImage.read_binary/2","type":"function"},{"doc":"Raising version of `read_binary/2`.","ref":"StbImage.html#read_binary!/2","title":"StbImage.read_binary!/2","type":"function"},{"doc":"Reads image from file at `path`.","ref":"StbImage.html#read_file/2","title":"StbImage.read_file/2","type":"function"},{"doc":"* `:channels` - The number of desired channels.\n    Use `0` for auto-detection. Defaults to 0.","ref":"StbImage.html#read_file/2-options","title":"Options - StbImage.read_file/2","type":"function"},{"doc":"{:ok, img} = StbImage.read_file(\"/path/to/image\")\n    {h, w, c} = img.shape\n    data = img.data\n\n    # If you know that the image is a 4-channel image and auto-detection failed\n    {:ok, img} = StbImage.read_file(\"/path/to/image\", channels: 4)\n    {h, w, c} = img.shape\n    img = img.data","ref":"StbImage.html#read_file/2-example","title":"Example - StbImage.read_file/2","type":"function"},{"doc":"Raising version of `read_file/2`.","ref":"StbImage.html#read_file!/2","title":"StbImage.read_file!/2","type":"function"},{"doc":"Decodes GIF image from a `binary` representing a GIF.","ref":"StbImage.html#read_gif_binary/1","title":"StbImage.read_gif_binary/1","type":"function"},{"doc":"{:ok, buffer} = File.read(\"/path/to/image\")\n    {:ok, frames, delays} = StbImage.read_gif_binary(buffer)\n    frame = Enum.at(frames, 0)\n    {h, w, 3} = frame.shape","ref":"StbImage.html#read_gif_binary/1-example","title":"Example - StbImage.read_gif_binary/1","type":"function"},{"doc":"Reads GIF image from file at `path`.","ref":"StbImage.html#read_gif_file/1","title":"StbImage.read_gif_file/1","type":"function"},{"doc":"{:ok, frames, delays} = StbImage.read_gif_file(\"/path/to/image\")\n    frame = Enum.at(frames, 0)\n    {h, w, 3} = frame.shape","ref":"StbImage.html#read_gif_file/1-example","title":"Example - StbImage.read_gif_file/1","type":"function"},{"doc":"Resizes the image into the given `output_h` and `output_w`.","ref":"StbImage.html#resize/3","title":"StbImage.resize/3","type":"function"},{"doc":"img = StbImage.new(raw_img, {h, w, channels})\n    StbImage.resize(raw_img, div(h, 2), div(w, 2))","ref":"StbImage.html#resize/3-example","title":"Example - StbImage.resize/3","type":"function"},{"doc":"Encodes image to a binary.\n\nThe supported formats are :jpg, :png, :bmp, :tga, :hdr.","ref":"StbImage.html#to_binary/2","title":"StbImage.to_binary/2","type":"function"},{"doc":"img = StbImage.new(raw_img, {h, w, channels})\n    binary = StbImage.to_binary(img, :png)","ref":"StbImage.html#to_binary/2-example","title":"Example - StbImage.to_binary/2","type":"function"},{"doc":"Converts a `StbImage` to a Nx tensor.\n\nIt accepts the same options as `Nx.from_binary/3`.","ref":"StbImage.html#to_nx/2","title":"StbImage.to_nx/2","type":"function"},{"doc":"Writes image to the file at `path`.\n\nThe supported formats are :jpg, :png, :bmp, :tga, :hdr.\n\nThe format is determined from the file extension, if possible.\nYou can also pass it explicitly via the `:format` option.\n\nReturns `:ok` on success and `{:error, reason}` otherwise.\n\nMake sure the directory you intend to write the file to exists.\nOtherwise, an error is returned.","ref":"StbImage.html#write_file/3","title":"StbImage.write_file/3","type":"function"},{"doc":"* `:format` - one of the supported image formats","ref":"StbImage.html#write_file/3-options","title":"Options - StbImage.write_file/3","type":"function"},{"doc":"Raising version of `write_file/3`.","ref":"StbImage.html#write_file!/3","title":"StbImage.write_file!/3","type":"function"}]}